@@ -4,7 +4,7 @@
  * Copyright 2001 James Aylett
  * Copyright 2001,2002 Ananova Ltd
  * Copyright 2002 Intercede 1749 Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011 Olly Betts
  * Copyright 2008 Thomas Viehmann
  *
  * This program is free software; you can redistribute it and/or
@@ -59,6 +59,7 @@
 #include "str.h"
 #include "stringutils.h"
 #include "transform.h"
+#include "urlencode.h"
 #include "unixperm.h"
 #include "values.h"
 #include "weight.h"
@@ -236,7 +237,76 @@ set_probabilistic(const string &oldp)
     }
 
     try {
-	unsigned f = qp.FLAG_DEFAULT;
+	unsigned f = 0;
+	map<string, string>::const_iterator i = option.lower_bound("flag_");
+	for (; i != option.end() && startswith(i->first, "flag_"); ++i) {
+	    if (i->second.empty()) continue;
+	    const string & s = i->first;
+	    switch (s[5]) {
+		case 'a':
+		    if (s == "flag_auto_multiword_synonyms") {
+			f |= Xapian::QueryParser::FLAG_AUTO_MULTIWORD_SYNONYMS;
+			break;
+		    }
+		    if (s == "flag_auto_synonyms") {
+			f |= Xapian::QueryParser::FLAG_AUTO_SYNONYMS;
+			break;
+		    }
+		    break;
+		case 'b':
+		    if (s == "flag_boolean") {
+			f |= Xapian::QueryParser::FLAG_BOOLEAN;
+			break;
+		    }
+		    if (s == "flag_boolean_any_case") {
+			f |= Xapian::QueryParser::FLAG_BOOLEAN_ANY_CASE;
+			break;
+		    }
+		    break;
+		case 'd':
+		    if (s == "flag_default") {
+			f |= Xapian::QueryParser::FLAG_DEFAULT;
+			break;
+		    }
+		    break;
+		case 'l':
+		    if (s == "flag_lovehate") {
+			f |= Xapian::QueryParser::FLAG_LOVEHATE;
+			break;
+		    }
+		    break;
+		case 'p':
+		    if (s == "flag_partial") {
+			f |= Xapian::QueryParser::FLAG_PARTIAL;
+			break;
+		    }
+		    if (s == "flag_phrase") {
+			f |= Xapian::QueryParser::FLAG_PHRASE;
+			break;
+		    }
+		    if (s == "flag_pure_not") {
+			f |= Xapian::QueryParser::FLAG_PURE_NOT;
+			break;
+		    }
+		    break;
+		case 's':
+		    if (s == "flag_spelling_correction") {
+			f |= Xapian::QueryParser::FLAG_SPELLING_CORRECTION;
+			break;
+		    }
+		    if (s == "flag_synonym") {
+			f |= Xapian::QueryParser::FLAG_SYNONYM;
+			break;
+		    }
+		    break;
+		case 'w':
+		    if (s == "flag_wildcard") {
+			f |= Xapian::QueryParser::FLAG_WILDCARD;
+			break;
+		    }
+		    break;
+	    }
+	}
 	if (option["spelling"] == "true")
 	    f |= qp.FLAG_SPELLING_CORRECTION;
 	query = qp.parse_query(query_string, f);
@@ -423,24 +493,6 @@ run_query()
     }
 }
 
-static string
-percent_encode(const string &str)
-{
-    string res;
-    const char *p = str.c_str();
-    while (true) {
-	unsigned char ch = *p++;
-	if (ch == 0) return res;
-	if (ch <= 32 || ch >= 127 || strchr("#%&+,/:;<=>?@[\\]^_{|}", ch)) {
-	    char buf[4];
-	    my_snprintf(buf, sizeof(buf), "%%%02x", ch);
-	    res.append(buf, 3);
-	} else {
-	    res += ch;
-	}
-    }
-}
-
 string
 html_escape(const string &str)
 {
@@ -1930,7 +1982,7 @@ eval(const string &fmt, const vector<string> &param)
 		value = Xapian::Unicode::toupper(args[0]);
 		break;
 	    case CMD_url:
-	        value = percent_encode(args[0]);
+		url_encode(value, args[0]);
 		break;
 	    case CMD_value: {
 		Xapian::docid id = q0;
@@ -2075,6 +2127,7 @@ parse_omegascript()
 	std::string output = eval_file(fmtname);
 	if (!set_content_type && !suppress_http_headers) {
 	    cout << "Content-Type: text/html" << std::endl;
+	    set_content_type = true;
 	}
 	cout << std::endl;
 	cout << output;
@@ -2083,6 +2136,7 @@ parse_omegascript()
 	// reported rather than giving a server error.
 	if (!set_content_type && !suppress_http_headers) {
 	    cout << "Content-Type: text/html" << std::endl;
+	    set_content_type = true;
 	}
 	cout << std::endl;
 	throw;
