@@ -3,7 +3,7 @@
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001 Sam Liddicott
  * Copyright 2001,2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -518,7 +518,7 @@ index_file(const char *fname, istream &stream,
 			if (prefix_needs_colon(term, value[0])) term += ':';
 			term += value;
 
-			doc.add_term(term);
+			doc.add_boolean_term(term);
 			break;
 		    }
 		    case Action::HASH: {
@@ -534,7 +534,8 @@ index_file(const char *fname, istream &stream,
 			break;
 		    case Action::LOAD: {
 			bool truncated = false;
-			if (!load_file(value, i->get_num_arg(), true,
+			// FIXME: Use NOATIME if we own the file or are root.
+			if (!load_file(value, i->get_num_arg(), NOCACHE,
 				       value, truncated)) {
 			    cerr << "Couldn't load file '" << value << "': "
 				 << strerror(errno) << endl;
@@ -606,7 +607,7 @@ again:
 			} catch (const Xapian::Error &e) {
 			    // Hmm, what happened?
 			    cout << "Caught exception in UNIQUE!" << endl;
-			    cout << "E: " << e.get_msg() << endl;
+			    cout << "E: " << e.get_description() << endl;
 			    database.commit();
 			    goto again;
 			}
@@ -643,13 +644,13 @@ again:
 			}
 			if (yyyymmdd.empty()) break;
 			// Date (YYYYMMDD)
-			doc.add_term("D" + yyyymmdd);
+			doc.add_boolean_term("D" + yyyymmdd);
 			yyyymmdd.resize(6);
 			// Month (YYYYMM)
-			doc.add_term("M" + yyyymmdd);
+			doc.add_boolean_term("M" + yyyymmdd);
 			yyyymmdd.resize(4);
 			// Year (YYYY)
-			doc.add_term("Y" + yyyymmdd);
+			doc.add_boolean_term("Y" + yyyymmdd);
 			break;
 		    }
 		    default:
@@ -693,7 +694,7 @@ again:
 		    if (verbose) cout << "Replace: " << docid << endl;
 		    repcount ++;
 		} catch (const Xapian::Error &e) {
-		    cout << "E: " << e.get_msg() << endl;
+		    cout << "E: " << e.get_description() << endl;
 		    // Possibly the document was deleted by another
 		    // process in the meantime...?
 		    docid = database.add_document(doc);
@@ -777,7 +778,7 @@ try {
 "      --overwrite     create the database anew (the default is to update if\n"
 "                      the database already exists)\n";
 	print_stemmer_help("");
-	print_help_and_version_help("", 'V');
+	print_help_and_version_help("");
 	exit(show_help ? 0 : 1);
     }
 
@@ -824,7 +825,7 @@ try {
     cout << "records (added, replaced, deleted) = (" << addcount << ", "
 	 << repcount << ", " << delcount << ")" << endl;
 } catch (const Xapian::Error &error) {
-    cout << "Exception: " << error.get_msg() << endl;
+    cout << "Exception: " << error.get_description() << endl;
     exit(1);
 } catch (const std::bad_alloc &) {
     cout << "Exception: std::bad_alloc" << endl;
