@@ -1,6 +1,6 @@
 /* xmlparse.cc: subclass of HtmlParser for parsing XML.
  *
- * Copyright (C) 2006,2009 Olly Betts
+ * Copyright (C) 2006,2009,2011 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,17 @@
 
 #include "xmlparse.h"
 
-void
+bool
 XmlParser::opening_tag(const string &)
 {
+    return true;
 }
 
-void
-XmlParser::closing_tag(const string &)
+bool
+XmlParser::closing_tag(const string &tag)
 {
+    // For OpenDocument, .docx, .xlsx, .pptx respectively.
+    if (tag == "text:p" || tag == "w:t" || tag == "t" || tag == "a:t")
+	pending_space = true;
+    return true;
 }
